from setuptools import setup, find_packages

setup(
  name='M_Ana_package',
  version='0.0.5',
  description='A Python Package for Data Manipulation and Analysis',
  long_description=open('README.txt').read() + '\n\n' + open('CHANGELOG.txt').read(),
  url='',  
  author='M_A', 
  keywords='data', 
  packages=find_packages(),
  install_requires=['plotly',
                    'plotly-express',
                    'matplotlib',
                    'scipy',
                    'pandas',
                    'numpy',
                    'sklearn',
                    'pyperclip',
                    'pyarrow',
                    'sas7bdat',
                    'pyreadstat',
                    'statsmodels',
                    'pyod',
                    'tensorflow',
                    'h5py',],
   classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
)